# Automatic changelog

<!--next-version-placeholder-->

## v0.2.0 (2021-04-13)
### Feature
* Add process validation and method to know if process is over ([`661b5d1`](https://gitlab.com/i3lab/mmcc/core/mmcc-framework/-/commit/661b5d1f893e55fddb566942d65f04c3a85f7b14))

## v0.1.0 (2021-03-27)
### Feature
* Named callbacks ([`02605e7`](https://gitlab.com/i3lab/mmcc/core/mmcc-framework/-/commit/02605e7038c1fe1fd6952b2c647fd84e0d07426e))